@@ -1,5 +1,10 @@
 """
-Fabric tools for managing Debian/Ubuntu packages
+Debian packages
+===============
+
+This module provides tools to manage Debian/Ubuntu packages
+and repositories.
+
 """
 from __future__ import with_statement
 
@@ -9,16 +14,17 @@ from fabric.api import *
 MANAGER = 'apt-get'
 
 
-def update_index():
+def update_index(quiet=True):
     """
-    Quietly update package index
+    Update APT package definitions.
     """
-    sudo("%s -q -q update" % MANAGER)
+    options = "-q -q" if quiet else ""
+    sudo("%s %s update" % (MANAGER, options))
 
 
 def upgrade(safe=True):
     """
-    Upgrade all packages
+    Upgrade all packages.
     """
     manager = MANAGER
     cmds = {'apt-get': {False: 'dist-upgrade', True: 'upgrade'},
@@ -29,7 +35,7 @@ def upgrade(safe=True):
 
 def is_installed(pkg_name):
     """
-    Check if .deb package is installed
+    Check if a package is installed.
     """
     with settings(hide('running', 'stdout', 'stderr', 'warnings'), warn_only=True):
         res = run("dpkg -s %(pkg_name)s" % locals())
@@ -43,7 +49,26 @@ def is_installed(pkg_name):
 
 def install(packages, update=False, options=None):
     """
-    Install .deb package(s)
+    Install one or more packages.
+
+    If *update* is ``True``, the package definitions will be updated
+    first, using :py:func:`~fabtools.deb.update_index`.
+
+    Extra *options* may be passed to ``apt-get`` if necessary.
+
+    Example::
+
+        import fabtools
+
+        # Update index, then install a single package
+        fabtools.deb.install('build-essential', update=True)
+
+        # Install multiple packages
+        fabtools.deb.install([
+            'python-dev',
+            'libxml2-dev',
+        ])
+
     """
     manager = MANAGER
     if update:
@@ -59,7 +84,12 @@ def install(packages, update=False, options=None):
 
 def uninstall(packages, purge=False, options=None):
     """
-    Remove .deb package(s)
+    Remove one or more packages.
+
+    If *purge* is ``True``, the package configuration files will be
+    removed from the system.
+
+    Extra *options* may be passed to ``apt-get`` if necessary.
     """
     manager = MANAGER
     command = "purge" if purge else "remove"
@@ -74,7 +104,21 @@ def uninstall(packages, purge=False, options=None):
 
 def preseed_package(pkg_name, preseed):
     """
-    Enable unattended package installation by preseeding debconf parameters
+    Enable unattended package installation by preseeding ``debconf``
+    parameters.
+
+    Example::
+
+        import fabtools
+
+        # Unattended install of Postfix mail server
+        fabtools.deb.preseed_package('postfix', {
+            'postfix/main_mailer_type': ('select', 'Internet Site'),
+            'postfix/mailname': ('string', 'example.com'),
+            'postfix/destinations': ('string', 'example.com, localhost.localdomain, localhost'),
+        })
+        fabtools.deb.install('postfix')
+
     """
     for q_name, _ in preseed.items():
         q_type, q_answer = _
@@ -83,8 +127,9 @@ def preseed_package(pkg_name, preseed):
 
 def get_selections():
     """
-    Get the state of dkpg selections
-    Returns dict with state => [packages]
+    Get the state of ``dkpg`` selections.
+
+    Returns a dict with state => [packages].
     """
     with settings(hide('stdout')):
         res = sudo('dpkg --get-selections')
@@ -97,7 +142,15 @@ def get_selections():
 
 def distrib_codename():
     """
-    Get the codename of the distrib
+    Get the codename of the distrib.
+
+    Example::
+
+        from fabtools.deb import distrib_codename
+
+        if distrib_codename() == 'precise':
+            print('Ubuntu 12.04 LTS')
+
     """
     with settings(hide('running', 'stdout')):
         return run('lsb_release --codename --short')
@@ -105,7 +158,19 @@ def distrib_codename():
 
 def add_apt_key(filename, update=True):
     """
-    Add an APT key
+    Trust packages signed with this public key.
+
+    Example::
+
+        import fabtools
+
+        # Download 3rd party APT public key
+        if not fabtools.is_file('rabbitmq-signing-key-public.asc'):
+            run('wget http://www.rabbitmq.com/rabbitmq-signing-key-public.asc')
+
+        # Tell APT to trust that key
+        fabtools.deb.add_apt_key('rabbitmq-signing-key-public.asc')
+
     """
     sudo('apt-key add %(filename)s' % locals())
     if update:
