@@ -5,24 +5,13 @@ import os.path
 from fabric.main import load_fabfile
 
 
-def short_doc(obj):
-    """
-    Returns the first line of the object's docstring
-    """
-    if obj.__doc__:
-        lines = obj.__doc__.strip(' \n').splitlines()
-        if lines:
-            return lines[0]
-    return None
-
-
 def load_tests(loader, suite, patterns):
     """
     Custom test loader for functional tests
     """
 
     # Try to add vagrant functional tests
-    from .vagrant import base_boxes, VagrantFunctionTestCase, VagrantTestSuite
+    from .vagrant import base_boxes, VagrantTestCase, VagrantTestSuite
     boxes = base_boxes()
     if boxes:
         vagrant_suite = VagrantTestSuite(boxes)
@@ -33,9 +22,8 @@ def load_tests(loader, suite, patterns):
             if fnmatch.fnmatch(filename, '[!_]*.py'):
                 fabfile = os.path.join(fabfiles, filename)
                 _, tasks, _ = load_fabfile(fabfile)
-                for task in tasks.values():
-                    test = VagrantFunctionTestCase(task,
-                        description=short_doc(task))
+                for name, callable in tasks.iteritems():
+                    test = VagrantTestCase(name, callable)
                     vagrant_suite.addTest(test)
 
         suite.addTest(vagrant_suite)
